CompositionCommand

Enum CompositionCommand 

pub enum CompositionCommand {
    SetWindowComposition {
        window_id: CompositorWindowId,
        composition: WindowCompositionSpec,
    },
    UpdateItemBounds {
        window_id: CompositorWindowId,
        item_id: CompositionItemId,
        bounds: Rect,
    },
    SetItemVisibility {
        window_id: CompositorWindowId,
        item_id: CompositionItemId,
        visible: bool,
    },
    SetItemHitTestRegions {
        window_id: CompositorWindowId,
        item_id: CompositionItemId,
        snapshot_id: u64,
        coordinate_space: HitTestCoordinateSpace,
        mode: HitTestRegionMode,
        regions: Vec<HitTestRegion>,
    },
    RemoveItem {
        window_id: CompositorWindowId,
        item_id: CompositionItemId,
    },
}
Declarative scene updates applied to a compositor-managed window.

Variants



SetWindowComposition

Replace the entire scene contents for a window.

Fields

window_id: CompositorWindowId

Window to update.

composition: WindowCompositionSpec

New composition snapshot for the window.



UpdateItemBounds

Update only the bounds of one existing scene item.

Fields

window_id: CompositorWindowId

Window that owns the item.

item_id: CompositionItemId

Item to move or resize.

bounds: Rect

New bounds in window coordinates.



SetItemVisibility

Update only the visibility of one existing scene item.

Fields

window_id: CompositorWindowId

Window that owns the item.

item_id: CompositionItemId

Item to show or hide.

visible: bool

New visibility state.



SetItemHitTestRegions

Replace the cached hit-test snapshot for one item.

Fields

window_id: CompositorWindowId

Window that owns the item.

item_id: CompositionItemId

Item that should receive the snapshot.

snapshot_id: u64

Monotonic snapshot identifier used to ignore stale updates.

coordinate_space: HitTestCoordinateSpace

Coordinate space used by the provided regions.

mode: HitTestRegionMode

How the listed regions should participate in hit-testing.

regions: Vec<HitTestRegion>

Regions interpreted according to mode.



RemoveItem

Remove one scene item from a window.

Fields

window_id: CompositorWindowId

Window that owns the item.

item_id: CompositionItemId

Item to remove.