pub enum HitTestRegionMode {
ConsumeListedRegions,
PassthroughListedRegions,
}Expand description
How a hit-test snapshot interprets its listed regions.
Variants
ConsumeListedRegions
Listed regions consume pointer input and all other bounds pass through.
PassthroughListedRegions
Listed regions pass pointer input through and all other bounds consume it.