pub enum SurfaceTarget {
BrowsingContext(BrowsingContextId),
TransientBrowsingContext(TransientBrowsingContextId),
}Expand description
Browser-managed surface target that can appear in the compositor scene.
Variants
BrowsingContext(BrowsingContextId)
A regular browsing context surface.
TransientBrowsingContext(TransientBrowsingContextId)
A transient browsing context surface such as an extension popup.